# load the data set
library( "frontier" )
data( "riceProdPhil" )

# estimate a Cobb-Douglas production function with fixed individual effects
library( "plm" )
riceCdFix <- plm( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ), 
   data = riceProdPhil, index =  c( "FMERCODE", "YEARDUM" ) )
summary( riceCdFix )
# alternatively
pDat <- plm.data( riceProdPhil, c( "FMERCODE", "YEARDUM" ) )
riceCdFixPd <- plm( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ), 
   data = pDat )
summary( riceCdFixPd )

# # estimate a Cobb-Douglas production function with fixed two-ways effects
# riceCdFix2 <- plm( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ), 
#    data = riceProdPhil, index =  c( "FMERCODE", "YEARDUM" ),
#    effect = "twoways" )
# summary( riceCdFix2 )
# # alternatively
# riceCdFixPd2 <- plm( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ), 
#    data = pDat, effect = "twoways" )
# summary( riceCdFixPd2 )
# 
# # extract individual fixed effects
# fixef( riceCdFix2 )
# # extract time fixed effects
# fixef( riceCdFix2, effect = "time" )

# # statistical significance of the fixed individual and time effects
# # estimate pooled model
# riceCdPool <- plm( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ), 
#    data = riceProdPhil, model = "pooling" )
# summary( riceCdPool )
# # alternatively
# riceCdPoolPd <- plm( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ), 
#    data = pDat, model = "pooling" )
# summary( riceCdPoolPd )
# # time effects
# pooltest( riceCdFix, riceCdFix2 )
# # individual & time effects
# pooltest( riceCdPool, riceCdFix2 )
# # individual effects
# pooltest( riceCdPool, riceCdFix )

# estimate a Cobb-Douglas production function with random individual effects
riceCdRan <- plm( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ), 
   data = riceProdPhil, index =  c( "FMERCODE", "YEARDUM" ),
   model = "random" )
summary( riceCdRan )
# alternatively
riceCdRanPd <- plm( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ), 
   data = pDat, model = "random" )
summary( riceCdRanPd )

# Hausman tests for the consistency of the random-effects estimators
phtest( riceCdFix, riceCdRan )

# # estimate a Cobb-Douglas production function with random two-ways effects
# riceCdRan2 <- plm( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ), 
#    data = riceProdPhil, index =  c( "FMERCODE", "YEARDUM" ),
#    effect = "twoways", model = "random" )
# summary( riceCdRan2 )
# # alternatively
# riceCdRanPd2 <- plm( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ), 
#    data = pDat, effect = "twoways", model = "random" )
# summary( riceCdRanPd2 )
# 
# # Hausman tests for the consistency of the random-effects estimators
# phtest( riceCdFix2, riceCdRan2 )
