library( "frontier" )
data( "riceProdPhil" )

# estimate a pooled Cobb-Douglas stochastic production frontier
riceSfaPool <- sfa( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ), 
   data = riceProdPhil )
summary( riceSfaPool )

# elasticity of scale
sum( coef( riceSfaPool )[ 2:4 ] )

# additional parameters
summary( riceSfaPool, extraPar = TRUE )

# plot a histogram of the estimated technical efficiencies
hist( efficiencies( riceSfaPool ) )

# observation (farm, year) has the lowest technical efficiency
riceProdPhil[ which.min( efficiencies( riceSfaPool ) ), ]

# LR test against OLS
lrtest( riceSfaPool )

# create data set with information on the panel structure
library( "plm" )
pDat <- plm.data( riceProdPhil, c( "FMERCODE", "YEARDUM" ) )

# estimate a Cobb-Douglas stochastic production frontier with time-invariant efficiency
riceSfaInvar <- sfa( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ), 
   data = pDat )
summary( riceSfaInvar )

efficiencies( riceSfaInvar )
plot( efficiencies( riceSfaPool ), efficiencies( riceSfaInvar, asInData = TRUE ) )

# estimate a Cobb-Douglas stochastic production frontier with time-varying efficiency
riceSfaVar <- sfa( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ), 
   data = pDat, timeEffect = TRUE )
summary( riceSfaVar )
lrtest( riceSfaInvar, riceSfaVar )

# estimate a 'True Fixed Effects' Cobb-Douglas stochastic production frontier
# with observation-specific technical efficiencies
riceProdPhil$FMERCODE <- factor( riceProdPhil$FMERCODE )
riceSfaTfe <- sfa( log( PROD ) ~ log( AREA ) + log( LABOR ) + log( NPK ) + 
      FMERCODE, data = riceProdPhil )
summary( riceSfaTfe )
lrtest( riceSfaPool, riceSfaTfe )
